==> kom%2B%2B-0.2.tar.gz: kom++-0.2/libkom++/map-cache.cc <==
// Create-on-demand map of mappings for conferences.
//
// $Id: map-cache.cc,v 1.3 1994/07/16 17:44:16 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include "kom-types.h"
#include "misc.h"
#include "map-cache.h"
#include "Conf_no.Text_mapping.CHMap.h"

Map_cache::Map_cache(const Conferences &c)
: m_conn(c.connection()), m_conf_cache(c.read_conf_cache()), mapmap()
{
}

Map_cache::Map_cache(const Map_cache&m)
{
    abort();
}

static Text_mapping bad_text_mapping;

Map_cache::Mtmap::Mtmap()
    : Conf_noText_mappingCHMap(bad_text_mapping, 50)
{
}

Map_cache& 
Map_cache::operator=(const Map_cache&m)
{
    abort();
}

Map_cache::~Map_cache()
{
}

void
Map_cache::clear()
{
    // +++ Not yet implemented.
}

Connection*
Map_cache::connection() const
{
    return m_conn;
}

 
Text_mapping
Map_cache::get(Conf_no cno)
{
    Text_mapping &r = mapmap[cno];
    if (!r.valid())
	r = Text_mapping(Conference(cno, m_conf_cache));
    return r;
}

Bool
Map_cache::Mtmap::present(Conf_no c) const
{
    return ((Map_cache::Mtmap*)this)->contains(c) ? TRUE : FALSE;
}

Text_mapping &
Map_cache::Mtmap::operator[](Conf_no c)
{
    return Conf_noText_mappingCHMap::operator[](c);
}

==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/map-cache.cc <==
// Create-on-demand map of mappings for conferences.
//
// $Id: map-cache.cc,v 1.4 1994/07/30 23:46:01 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include "kom-types.h"
#include "misc.h"
#include "map-cache.h"
#include "Conf_no.Text_mapping.CHMap.h"

Map_cache::Map_cache(const Conferences &c)
: m_conn(c.connection()), m_conf_cache(c.read_conf_cache()), mapmap()
{
}

//Map_cache::Map_cache(const Map_cache&m)
//{
//    abort();
//}

static Text_mapping bad_text_mapping;

Map_cache::Mtmap::Mtmap()
    : Conf_noText_mappingCHMap(bad_text_mapping, 50)
{
}

//Map_cache& 
//Map_cache::operator=(const Map_cache&m)
//{
//    abort();
//}

Map_cache::~Map_cache()
{
}

void
Map_cache::clear()
{
    // FIXME +++ Not yet implemented.
}

Connection*
Map_cache::connection() const
{
    return m_conn;
}

 
Text_mapping
Map_cache::get(Conf_no cno)
{
    Text_mapping &r = mapmap[cno];
    if (!r.valid())
	r = Text_mapping(Conference(cno, m_conf_cache));
    return r;
}

Bool
Map_cache::Mtmap::present(Conf_no c) const
{
    return ((Map_cache::Mtmap*)this)->contains(c) ? TRUE : FALSE;
}

Text_mapping &
Map_cache::Mtmap::operator[](Conf_no c)
{
    return Conf_noText_mappingCHMap::operator[](c);
}
